@@ -11,14 +11,12 @@ class Filter(Absorber):
         self._material = material
         self._thickness = thickness
 
-
         # support text containg name of variable, help text and unit. Will be stored in self._support_dictionary
         self._set_support_text([
-                    ("name"          , "Name"                              , ""),
-                    ("boundary_shape", ""                                  , ""),
-                    ("material"      , "Material (symbol, formula or name)", ""),
-                    ("thickness"     , "Thickness "                        , "m"),
-            ] )
+                    ("material"      , "Material (symbol, formula or name)",    "" ),
+                    ("thickness"     , "Thickness ",                            "m" ),
+            ])
+
     def get_material(self):
         return self._material
 
