@@ -216,8 +216,6 @@ class Ellipsoid(SurfaceShape):
 
         return p, q
 
-
-
 class EllipticalCylinder(Ellipsoid, Cylinder):
     def __init__(self, 
                  min_axis=0.0, 
@@ -499,7 +497,7 @@ class Toroid(SurfaceShape):
 
 # This is exactly the same as OasysSurfaceData
 # class OasysSurfaceData(object):
-class SurfaceData(SurfaceShape):
+class NumericalMesh(SurfaceShape):
     def __init__(self,
                  xx=None,
                  yy=None,
